@@ -188,6 +188,6 @@ Application.run(Window)
 
 class Resize(ResizeHandle):
     def __init__(self, parent: Widget, widget: Widget):
-        self.build(parent.Me)
+        super().__init__(parent.Me)
         self.addWidget(widget)
         self.upDate()
\ No newline at end of file
